@@ -71,6 +71,7 @@ __all__ = (
     "DescribeJobQueuesResponseTypeDef",
     "DescribeJobsResponseTypeDef",
     "ListJobsResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "NodeOverridesTypeDef",
     "PaginatorConfigTypeDef",
     "RegisterJobDefinitionResponseTypeDef",
@@ -120,6 +121,7 @@ _RequiredComputeEnvironmentDetailTypeDef = TypedDict(
 _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
     "_OptionalComputeEnvironmentDetailTypeDef",
     {
+        "tags": Dict[str, str],
         "type": Literal["MANAGED", "UNMANAGED"],
         "state": Literal["ENABLED", "DISABLED"],
         "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
@@ -276,6 +278,7 @@ _OptionalJobDefinitionTypeDef = TypedDict(
         "containerProperties": "ContainerPropertiesTypeDef",
         "timeout": "JobTimeoutTypeDef",
         "nodeProperties": "NodePropertiesTypeDef",
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -305,6 +308,7 @@ _RequiredJobDetailTypeDef = TypedDict(
 _OptionalJobDetailTypeDef = TypedDict(
     "_OptionalJobDetailTypeDef",
     {
+        "jobArn": str,
         "attempts": List["AttemptDetailTypeDef"],
         "statusReason": str,
         "createdAt": int,
@@ -317,6 +321,7 @@ _OptionalJobDetailTypeDef = TypedDict(
         "nodeProperties": "NodePropertiesTypeDef",
         "arrayProperties": "ArrayPropertiesDetailTypeDef",
         "timeout": "JobTimeoutTypeDef",
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -341,6 +346,7 @@ _OptionalJobQueueDetailTypeDef = TypedDict(
     {
         "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
         "statusReason": str,
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -354,6 +360,7 @@ _RequiredJobSummaryTypeDef = TypedDict("_RequiredJobSummaryTypeDef", {"jobId": s
 _OptionalJobSummaryTypeDef = TypedDict(
     "_OptionalJobSummaryTypeDef",
     {
+        "jobArn": str,
         "createdAt": int,
         "status": Literal[
             "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
@@ -542,6 +549,10 @@ class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJob
     pass
 
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
+)
+
 NodeOverridesTypeDef = TypedDict(
     "NodeOverridesTypeDef",
     {"numNodes": int, "nodePropertyOverrides": List["NodePropertyOverrideTypeDef"]},
@@ -557,7 +568,19 @@ RegisterJobDefinitionResponseTypeDef = TypedDict(
     {"jobDefinitionName": str, "jobDefinitionArn": str, "revision": int},
 )
 
-SubmitJobResponseTypeDef = TypedDict("SubmitJobResponseTypeDef", {"jobName": str, "jobId": str})
+_RequiredSubmitJobResponseTypeDef = TypedDict(
+    "_RequiredSubmitJobResponseTypeDef", {"jobName": str, "jobId": str}
+)
+_OptionalSubmitJobResponseTypeDef = TypedDict(
+    "_OptionalSubmitJobResponseTypeDef", {"jobArn": str}, total=False
+)
+
+
+class SubmitJobResponseTypeDef(
+    _RequiredSubmitJobResponseTypeDef, _OptionalSubmitJobResponseTypeDef
+):
+    pass
+
 
 UpdateComputeEnvironmentResponseTypeDef = TypedDict(
     "UpdateComputeEnvironmentResponseTypeDef",
